"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useRandFile = exports.createRandomFileIfNotExist = exports.createRandomFile = void 0;
// ---------------------------------------------------------------------------------------------------------------------
// node-opcua-pki
// ---------------------------------------------------------------------------------------------------------------------
// Copyright (c) 2014-2022 - Etienne Rossignon - etienne.rossignon (at) gadz.org
// Copyright (c) 2022-2023 - Sterfive.com
// ---------------------------------------------------------------------------------------------------------------------
//
// This  project is licensed under the terms of the MIT license.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
// documentation files (the "Software"), to deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so,  subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the
// Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
// WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
// COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
// ---------------------------------------------------------------------------------------------------------------------
const path = require("path");
const fs = require("fs");
const config_1 = require("../config");
const execute_openssl_1 = require("./execute_openssl");
const common_1 = require("../common");
const q = common_1.quote;
function createRandomFile(randomFile, options, callback) {
    // istanbul ignore next
    if (!useRandFile()) {
        return callback();
    }
    (0, execute_openssl_1.execute_openssl)("rand " + " -out " + q(randomFile) + " -hex 256", options, (err) => {
        callback(err ? err : undefined);
    });
}
exports.createRandomFile = createRandomFile;
function createRandomFileIfNotExist(randomFile, options, callback) {
    const randomFilePath = options.cwd ? path.join(options.cwd, randomFile) : randomFile;
    if (fs.existsSync(randomFilePath)) {
        return callback();
    }
    else {
        createRandomFile(randomFile, options, callback);
    }
}
exports.createRandomFileIfNotExist = createRandomFileIfNotExist;
function useRandFile() {
    // istanbul ignore next
    if (config_1.g_config.opensslVersion && config_1.g_config.opensslVersion.toLowerCase().indexOf("libressl") > -1) {
        return false;
    }
    return true;
}
exports.useRandFile = useRandFile;
//# sourceMappingURL=_create_random_file.js.map